@@ -2,7 +2,7 @@
 
 source h-manifest.conf
 
-[[ "$CUSTOM_URL" = "" ]] && echo "Using default CUSTOM_URL" && CUSTOM_URL="stratum+ssl://nlb-gnbhhkqxxdgt9wc6ou.cn-chengdu.nlb.aliyuncs.com:4420"
+[[ "$CUSTOM_URL" = "" ]] && echo "Using default CUSTOM_URL" && CUSTOM_URL="stratum+tcp://aleo-asia.f2pool.com:4400"
 if echo "$CUSTOM_USER_CONFIG"|grep GPU_INDEX;then
     GPU_INDEX=$(echo "$CUSTOM_USER_CONFIG" |head -1)
 fi
